.. -*-restructuredtext-*-

.. image:: https://travis-ci.org/ubernostrum/django-contact-form.svg?branch=master
    :target: https://travis-ci.org/ubernostrum/django-contact-form

This application provides extensible contact-form functionality for
`Django <https://www.djangoproject.com/>`_ sites.

Full documentation for all functionality is included and is also
`available online <http://django-contact-form.readthedocs.io/>`_.